/*
* TeamSpeak 3 server minimal sample
*
* Copyright (c) 2007-2017 TeamSpeak-Systems
*/
#include "common.h"

#include <teamspeak/public_definitions.h>
#include <teamspeak/serverlib.h>
#include <teamspeak/serverlib_publicdefinitions.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

int main() {
    /* Create struct for callback function pointers */
    struct ServerLibFunctions funcs;

    /* Initialize all callbacks with NULL */
    memset(&funcs, 0, sizeof(struct ServerLibFunctions));

    /* Initialize server lib with callbacks */
    CHECK_ERROR_FATAL(ts3server_initServerLib(&funcs, LogType_CONSOLE, NULL));

    /* Create virtual server using default port 9987 with max 10 slots */
    /* listen on any address on ipv4 and ipv6 (it is also possible to enter multiple ipv4 and ipv6 addresses here) */
    uint64 server_id;
    CHECK_ERROR_FATAL(ts3server_createVirtualServer(9987, "0.0.0.0, ::", "TeamSpeak SDK Testserver", "", 10, &server_id));

    /* Create Channel Part */
    uint64 channel_parent_id = 0;
    uint64 channel_id;
    
    /* Set data of new channel. Use channelID of 0 for creating channels. */
    CHECK_ERROR(ts3server_setChannelVariableAsString(server_id, 0, CHANNEL_NAME,                "Test channel name"));
    CHECK_ERROR(ts3server_setChannelVariableAsString(server_id, 0, CHANNEL_TOPIC,               "Test channel topic"));
    CHECK_ERROR(ts3server_setChannelVariableAsString(server_id, 0, CHANNEL_DESCRIPTION,         "Test channel description"));
    CHECK_ERROR(ts3server_setChannelVariableAsInt   (server_id, 0, CHANNEL_FLAG_PERMANENT,      1));
    CHECK_ERROR(ts3server_setChannelVariableAsInt   (server_id, 0, CHANNEL_FLAG_SEMI_PERMANENT, 0));

    /* Flush changes to server */
    CHECK_ERROR(ts3server_flushChannelCreation(server_id, channel_parent_id, &channel_id));

    printf("\nCreated channel: %llu\n\n", channel_id);

    /* Delete Channel Part */
    int force = 1;

    /* Here we delete the channel we create with flushChannelCreation */
    CHECK_ERROR(ts3server_channelDelete(server_id, channel_id, force));

    /* Wait for user input */
    printf("\n--- Press Return to shutdown server and exit ---\n");
    getchar();

    /* Stop virtual server */
    CHECK_ERROR_FATAL(ts3server_stopVirtualServer(server_id));

    /* Shutdown server lib */
    CHECK_ERROR_FATAL(ts3server_destroyServerLib());

    return 0;
}
